@@ -77,6 +77,15 @@ static const gunichar one_code[] = {185, 178, 179, 188, 189, 190, 0};
 /* µ ¶ ® ¿ ¡ |  */
 static const gunichar misc_code[] = {181, 182, 174, 191, 161, 124, 0};
 
+/* language/region specific character groups */
+/* South Africa: Venda, Tswana and Northern Sotho */
+/* static const gchar *ZA_list = "ḓḽṋṱḒḼṊṰṅṄšŠ"; */
+static const gunichar ZA_code[] = {7699, 7741, 7755, 7793, 7698, 7740, 7754, 7792, 7749, 7748, 353, 352, 0};
+/* South Africa: Afrikaans */
+/* static const gchar *af_ZA_list = "áéíóúýêîôûèäëïöüÁÉÍÓÚÝÊÎÔÛÈÄËÏÖÜ"; */
+static const gunichar af_ZA_code[] = {225, 233, 237, 243, 250, 253, 234, 238, 244, 251, 232, 228, 235, 239, 246, 252, 193, 201, 205, 211, 218, 221, 202, 206, 212, 219, 200, 196, 203, 207, 214, 220, 0};
+
+
 static const gunichar * const chartable[] = {
 	def_code,
 	a_code,
@@ -98,7 +107,9 @@ static const gunichar * const chartable[] = {
 	quote_code,
 	currency_code,
 	one_code,
-	misc_code
+	misc_code,
+	ZA_code,
+	af_ZA_code
 };
 
 gboolean
@@ -147,7 +158,7 @@ selection_clear_cb (GtkWidget *widget, GdkEventSelection *event,
   charpick_data *curr_data = data;
   
   if (curr_data->last_toggle_button)
-    gtk_toggle_button_set_state (curr_data->last_toggle_button, FALSE);
+    gtk_toggle_button_set_active (curr_data->last_toggle_button, FALSE);
 
   curr_data->last_toggle_button = NULL;
   return TRUE;
@@ -309,7 +320,7 @@ populate_menu (charpick_data *curr_data)
 	while (list) {
 		gchar *string = list->data;
 		menuitem = gtk_radio_menu_item_new_with_label (group, string);
-		group = gtk_radio_menu_item_group (GTK_RADIO_MENU_ITEM (menuitem));
+		group = gtk_radio_menu_item_get_group (GTK_RADIO_MENU_ITEM (menuitem));
 		gtk_widget_show (menuitem);
 		g_object_set_data (G_OBJECT (menuitem), "string", string);
 		g_signal_connect (G_OBJECT (menuitem), "activate",
@@ -331,9 +342,9 @@ get_menu_pos (GtkMenu *menu, gint *x, gint *y, gboolean *push_in, gpointer data)
 	gint screen_width, screen_height;
 	
 	gtk_widget_size_request (GTK_WIDGET (menu), &reqmenu);
-	gdk_window_get_origin (GTK_WIDGET (curr_data->applet)->window, &tempx, &tempy);
-     	gdk_window_get_geometry (GTK_WIDGET (curr_data->applet)->window, NULL, NULL,
-     			      &width, &height, NULL);
+	gdk_window_get_origin (GDK_WINDOW (gtk_widget_get_window(curr_data->applet)), &tempx, &tempy);
+     	gdk_window_get_geometry (GDK_WINDOW (gtk_widget_get_window(curr_data->applet)), NULL, NULL,
+     				 &width, &height, NULL);
      			      
      	switch (panel_applet_get_orient (PANEL_APPLET (curr_data->applet))) {
      	case PANEL_APPLET_ORIENT_DOWN:
@@ -358,7 +369,7 @@ get_menu_pos (GtkMenu *menu, gint *x, gint *y, gboolean *push_in, gpointer data)
 static void
 chooser_button_clicked (GtkButton *button, charpick_data *curr_data)
 {
-	if (GTK_WIDGET_VISIBLE (curr_data->menu))
+	if (gtk_widget_get_visible (curr_data->menu))
 		gtk_menu_popdown (GTK_MENU (curr_data->menu));
 	else {
 		gtk_menu_set_screen (GTK_MENU (curr_data->menu),
@@ -494,10 +505,10 @@ build_table(charpick_data *p_curr_data)
     g_object_set_data (G_OBJECT (toggle_button[i]), "unichar", 
 				GINT_TO_POINTER(g_utf8_get_char (label)));
     g_signal_connect (GTK_OBJECT (toggle_button[i]), "toggled",
-                        (GtkSignalFunc) toggle_button_toggled_cb,
+		      G_CALLBACK (toggle_button_toggled_cb),
                         p_curr_data);
     g_signal_connect (GTK_OBJECT (toggle_button[i]), "button_press_event", 
-                        (GtkSignalFunc) button_press_hack, p_curr_data->applet);
+                      G_CALLBACK (button_press_hack), p_curr_data->applet);
   }
   
   if (p_curr_data->panel_vertical) {
@@ -795,10 +806,10 @@ charpicker_applet_fill (PanelApplet *applet)
                             utf8_atom,
 			    0);
   g_signal_connect (GTK_OBJECT (curr_data->applet), "selection_get",
-		      GTK_SIGNAL_FUNC (charpick_selection_handler),
+		      G_CALLBACK (charpick_selection_handler),
 		      curr_data);
   g_signal_connect (GTK_OBJECT (curr_data->applet), "selection_clear_event",
-		      GTK_SIGNAL_FUNC (selection_clear_cb),
+		      G_CALLBACK (selection_clear_cb),
 		      curr_data);
  
   make_applet_accessible (GTK_WIDGET (applet));
