@@ -25,7 +25,6 @@
 
 #include <gtk/gtk.h>
 #include <gdk/gdkkeysyms.h>
-#include <libgnomeui/gnome-help.h>
 #include <panel-applet.h>
 #include <panel-applet-gconf.h>
 #include <glib/gi18n.h>
@@ -420,6 +419,7 @@ cpufreq_applet_popup_position_menu (GtkMenu  *menu,
 {
         GtkWidget      *widget;
         GtkRequisition  requisition;
+        GtkAllocation   allocation;
         gint            menu_xpos;
         gint            menu_ypos;
 
@@ -427,10 +427,12 @@ cpufreq_applet_popup_position_menu (GtkMenu  *menu,
 
         gtk_widget_size_request (GTK_WIDGET (menu), &requisition);
 
-        gdk_window_get_origin (widget->window, &menu_xpos, &menu_ypos);
+        gdk_window_get_origin (gtk_widget_get_window (widget), &menu_xpos, &menu_ypos);
 
-        menu_xpos += widget->allocation.x;
-        menu_ypos += widget->allocation.y;
+	gtk_widget_get_allocation (widget, &allocation);
+
+        menu_xpos += allocation.x;
+        menu_ypos += allocation.y;
 
         switch (panel_applet_get_orient (PANEL_APPLET (widget))) {
         case PANEL_APPLET_ORIENT_DOWN:
@@ -438,14 +440,14 @@ cpufreq_applet_popup_position_menu (GtkMenu  *menu,
                 if (menu_ypos > gdk_screen_get_height (gtk_widget_get_screen (widget)) / 2)
                         menu_ypos -= requisition.height;
                 else
-                        menu_ypos += widget->allocation.height;
+                        menu_ypos += allocation.height;
                 break;
         case PANEL_APPLET_ORIENT_RIGHT:
         case PANEL_APPLET_ORIENT_LEFT:
                 if (menu_xpos > gdk_screen_get_width (gtk_widget_get_screen (widget)) / 2)
                         menu_xpos -= requisition.width;
                 else
-                        menu_xpos += widget->allocation.width;
+                        menu_xpos += allocation.width;
                 break;
         default:
                 g_assert_not_reached ();
@@ -531,19 +533,22 @@ static void
 cpufreq_applet_change_orient (PanelApplet *pa, PanelAppletOrient orient)
 {
         CPUFreqApplet *applet;
+        GtkAllocation  allocation;
         gint           size;
 
         applet = CPUFREQ_APPLET (pa);
 
         applet->orient = orient;
 
+        gtk_widget_get_allocation (GTK_WIDGET (applet), &allocation);
+
         if ((orient == PANEL_APPLET_ORIENT_LEFT) ||
             (orient == PANEL_APPLET_ORIENT_RIGHT)) {
-                size = GTK_WIDGET (applet)->allocation.width;
+                size = allocation.width;
 		gtk_alignment_set (GTK_ALIGNMENT (applet->container),
 				   0.5, 0.5, 0, 0);
         } else {
-                size = GTK_WIDGET (applet)->allocation.height;
+                size = allocation.height;
 		gtk_alignment_set (GTK_ALIGNMENT (applet->container),
 				   0, 0.5, 0, 0);
         }
@@ -570,9 +575,10 @@ cpufreq_applet_help_cb (BonoboUIComponent *uic,
 {
         GError *error = NULL;
            
-        gnome_help_display_on_screen ("cpufreq-applet", NULL,
-                                      gtk_widget_get_screen (GTK_WIDGET (applet)),
-                                      &error);
+	gtk_show_uri (gtk_widget_get_screen (GTK_WIDGET (applet)),
+			"ghelp:cpufreq-applet",
+			gtk_get_current_event_time (),
+			&error);
 
         if (error) {
                 cpufreq_utils_display_error (_("Could not open help document"),
@@ -814,7 +820,7 @@ cpufreq_applet_get_widget_size (CPUFreqApplet *applet,
         GtkRequisition  req;
         gint            size;
 
-        if (!GTK_WIDGET_VISIBLE (widget))
+        if (!gtk_widget_get_visible (widget))
                 return 0;
 	
         gtk_widget_size_request (widget, &req);
