@@ -51,7 +51,7 @@ static void	gnome_volume_applet_class_init	(GnomeVolumeAppletClass *klass);
 static void	gnome_volume_applet_init	(GnomeVolumeApplet *applet);
 static void	gnome_volume_applet_dispose	(GObject   *object);
 
-static void     gnome_volume_applet_size_allocate (GtkWidget     *widget, 
+static void     gnome_volume_applet_size_allocate (GtkWidget     *widget,
 						   GtkAllocation *allocation);
 
 static void	gnome_volume_applet_popup_dock	(GnomeVolumeApplet *applet);
@@ -66,7 +66,7 @@ static gboolean	gnome_volume_applet_button	(GtkWidget *widget,
 						 GdkEventButton *event);
 gboolean	gnome_volume_applet_key		(GtkWidget *widget,
 						 GdkEventKey *event);
-static gdouble  gnome_volume_applet_get_volume  (GstMixer *mixer, 
+static gdouble  gnome_volume_applet_get_volume  (GstMixer *mixer,
 						 GstMixerTrack *track);
 
 static void	gnome_volume_applet_background	(PanelApplet *panel_applet,
@@ -123,11 +123,14 @@ init_pixbufs (GnomeVolumeApplet *applet)
     NULL
   };
   gint n;
-  
+
   for (n = 0; pix_filenames[n] != NULL; n++) {
-    if (applet->pix[n])
+    if (applet->pix[n]) {
       g_object_unref (applet->pix[n]);
-    
+      applet->pix[n] = NULL; // gnome_icon_theme_load_icon can call us
+                             // recursively, so we have to be careful.
+    }
+
     applet->pix[n] = gtk_icon_theme_load_icon (gtk_icon_theme_get_default (),
 					       pix_filenames[n],
 					       applet->panel_size - 4,
@@ -282,7 +285,7 @@ select_tracks (GstElement *element,
     if (active_track_name_list) {
       for (i = 0; active_track_name_list[i] != NULL; i++) {
 	gchar *track_test = active_track_name_list[i];
-	
+
 	if (!strcmp (track_test, track->label))
 	  active_tracks = g_list_append (active_tracks, track);
       }
@@ -294,7 +297,7 @@ select_tracks (GstElement *element,
 
   if (!active_tracks && track_fallback)
     active_tracks = g_list_append (active_tracks, track_fallback);
-    
+
   if (!active_tracks && reset_state) {
     gst_element_set_state (element, GST_STATE_NULL);
   }
@@ -346,7 +349,7 @@ select_element_and_track (GnomeVolumeApplet *applet,
       }
     }
   }
-  
+
   if (!active_element)
     return FALSE;
 
@@ -414,7 +417,7 @@ gnome_volume_applet_setup (GnomeVolumeApplet *applet,
   if (res) {
     first_track = g_list_first (applet->tracks)->data;
 
-    applet->adjustment = GTK_ADJUSTMENT (gtk_adjustment_new (50, 0, 100, 
+    applet->adjustment = GTK_ADJUSTMENT (gtk_adjustment_new (50, 0, 100,
 							     4, 10, 0));
     /* We want a reference from the applet as well as from the dock it
      * will be attached to. */
@@ -422,8 +425,8 @@ gnome_volume_applet_setup (GnomeVolumeApplet *applet,
     g_signal_connect (applet->adjustment, "value-changed",
 		      G_CALLBACK (cb_volume), applet);
 
-    gtk_adjustment_set_value (applet->adjustment, 
-			      gnome_volume_applet_get_volume (applet->mixer, 
+    gtk_adjustment_set_value (applet->adjustment,
+			      gnome_volume_applet_get_volume (applet->mixer,
 							      first_track));
   }
 
@@ -431,7 +434,7 @@ gnome_volume_applet_setup (GnomeVolumeApplet *applet,
 				   panel_applet_get_orient (PANEL_APPLET (applet)));
 
   /* menu - done here because bonobo is intialized now */
-  panel_applet_setup_menu_from_file (PANEL_APPLET (applet), 
+  panel_applet_setup_menu_from_file (PANEL_APPLET (applet),
 				     DATADIR,
 				     "GNOME_MixerApplet.xml",
 				     NULL, verbs, applet);
@@ -559,35 +562,39 @@ gnome_volume_applet_get_dock_position (GnomeVolumeApplet *applet,
 				       gint *_x, gint *_y)
 {
   GtkWidget *widget = GTK_WIDGET (applet);
+  GtkAllocation widget_allocation, dock_allocation;
   gint x, y;
 
-  gdk_window_get_origin (widget->window, &x, &y);
+  gtk_widget_get_allocation (GTK_WIDGET (applet->dock), &dock_allocation);
+  gtk_widget_get_allocation (widget, &widget_allocation);
+
+  gdk_window_get_origin (gtk_widget_get_window (widget), &x, &y);
   switch (panel_applet_get_orient (PANEL_APPLET (applet))) {
     case PANEL_APPLET_ORIENT_DOWN:
-      x += widget->allocation.x;
-      x -= (GTK_WIDGET (applet->dock)->allocation.width -
-          widget->allocation.width) / 2;
-      y += widget->allocation.height + widget->allocation.y;
+      x += widget_allocation.x;
+      x -= (dock_allocation.width -
+          widget_allocation.width) / 2;
+      y += widget_allocation.height + widget_allocation.y;
       break;
     case PANEL_APPLET_ORIENT_UP:
-      x += widget->allocation.x;
-      x -= (GTK_WIDGET (applet->dock)->allocation.width -
-          widget->allocation.width) / 2;
-      y += widget->allocation.y;
-      y -= GTK_WIDGET (applet->dock)->allocation.height;
+      x += widget_allocation.x;
+      x -= (dock_allocation.width -
+          widget_allocation.width) / 2;
+      y += widget_allocation.y;
+      y -= dock_allocation.height;
       break;
     case PANEL_APPLET_ORIENT_RIGHT:
-      x += widget->allocation.width + widget->allocation.x;
-      y += widget->allocation.y;
-      y -= (GTK_WIDGET (applet->dock)->allocation.height -
-          widget->allocation.height) / 2;
+      x += widget_allocation.width + widget_allocation.x;
+      y += widget_allocation.y;
+      y -= (dock_allocation.height -
+          widget_allocation.height) / 2;
       break;
     case PANEL_APPLET_ORIENT_LEFT:
-      x += widget->allocation.x;
-      x -= GTK_WIDGET (applet->dock)->allocation.width;
-      y += widget->allocation.y;
-      y -= (GTK_WIDGET (applet->dock)->allocation.height -
-          widget->allocation.height) / 2;
+      x += widget_allocation.x;
+      x -= dock_allocation.width;
+      y += widget_allocation.y;
+      y -= (dock_allocation.height -
+          widget_allocation.height) / 2;
       break;
     default:
       g_assert_not_reached ();
@@ -725,7 +732,7 @@ gnome_volume_applet_run_mixer (GnomeVolumeApplet *applet)
  */
 
 /* This is not static so we can inject external events
- * into the applet. Its to work around a GTK+ misfeature. See dock.c 
+ * into the applet. Its to work around a GTK+ misfeature. See dock.c
  * for details. */
 
 gboolean
@@ -746,13 +753,13 @@ gnome_volume_applet_scroll (GtkWidget      *widget,
         gdouble volume = gtk_adjustment_get_value (applet->adjustment);
 
         if (event->direction == GDK_SCROLL_UP) {
-          volume += applet->adjustment->step_increment;
-          if (volume > applet->adjustment->upper)
-            volume = applet->adjustment->upper;
+          volume += gtk_adjustment_get_step_increment (applet->adjustment);
+          if (volume > gtk_adjustment_get_upper (applet->adjustment))
+            volume = gtk_adjustment_get_upper (applet->adjustment);
         } else {
-          volume -= applet->adjustment->step_increment;
-          if (volume < applet->adjustment->lower)
-            volume = applet->adjustment->lower;
+          volume -= gtk_adjustment_get_step_increment (applet->adjustment);
+          if (volume < gtk_adjustment_get_lower (applet->adjustment))
+            volume = gtk_adjustment_get_lower (applet->adjustment);
         }
 
         gtk_adjustment_set_value (applet->adjustment, volume);
@@ -775,11 +782,11 @@ gnome_volume_applet_button (GtkWidget      *widget,
 {
   GnomeVolumeApplet *applet = GNOME_VOLUME_APPLET (widget);
 
-  if (event->window != GTK_WIDGET (applet)->window &&
+  if (event->window != gtk_widget_get_window (GTK_WIDGET (applet)) &&
       event->type == GDK_BUTTON_PRESS) {
     gnome_volume_applet_popdown_dock (applet);
     return TRUE;
-  } else if (event->window == GTK_WIDGET (applet)->window) {
+  } else if (event->window == gtk_widget_get_window (GTK_WIDGET (applet))) {
     switch (event->button) {
       case 1:
         switch (event->type) {
@@ -819,7 +826,7 @@ gnome_volume_applet_button (GtkWidget      *widget,
 }
 
 /* This is not static so we can inject external events
- * into the applet. Its to work around a GTK+ misfeature. See dock.c 
+ * into the applet. Its to work around a GTK+ misfeature. See dock.c
  * for details. */
 
 gboolean
@@ -866,21 +873,21 @@ gnome_volume_applet_key (GtkWidget   *widget,
       if (event->state != 0)
         break;
 
-      if (event->keyval == GDK_Up || event->keyval == GDK_Down 
+      if (event->keyval == GDK_Up || event->keyval == GDK_Down
          ||event->keyval == GDK_Left)
-        increment = applet->adjustment->step_increment;
+        increment = gtk_adjustment_get_step_increment (applet->adjustment);
       else
-        increment = applet->adjustment->page_increment;
+        increment = gtk_adjustment_get_page_increment (applet->adjustment);
 
       if (event->keyval == GDK_Page_Up || event->keyval == GDK_Up
          ||event->keyval == GDK_Right) {
         volume += increment;
-        if (volume > applet->adjustment->upper)
-          volume = applet->adjustment->upper;
+        if (volume > gtk_adjustment_get_upper (applet->adjustment))
+          volume = gtk_adjustment_get_upper (applet->adjustment);
       } else {
         volume -= increment;
-        if (volume < applet->adjustment->lower)
-          volume = applet->adjustment->lower;
+        if (volume < gtk_adjustment_get_lower (applet->adjustment))
+          volume = gtk_adjustment_get_lower (applet->adjustment);
       }
 
       gtk_adjustment_set_value (applet->adjustment, volume);
@@ -930,7 +937,7 @@ gnome_volume_applet_orientation	(PanelApplet *_applet,
     PANEL_APPLET_CLASS (parent_class)->change_orient (_applet, orientation);
 }
 
-void gnome_volume_applet_size_allocate (GtkWidget     *widget, 
+void gnome_volume_applet_size_allocate (GtkWidget     *widget,
 					GtkAllocation *allocation)
 {
   GnomeVolumeApplet *applet = GNOME_VOLUME_APPLET (widget);
@@ -940,7 +947,7 @@ void gnome_volume_applet_size_allocate (GtkWidget     *widget,
     GTK_WIDGET_CLASS (parent_class)->size_allocate (widget, allocation);
 
   orient = panel_applet_get_orient (PANEL_APPLET (applet));
-  
+
   if (orient == PANEL_APPLET_ORIENT_UP || orient == PANEL_APPLET_ORIENT_DOWN) {
     if (applet->panel_size == allocation->height)
       return;
@@ -980,7 +987,7 @@ gnome_volume_applet_background (PanelApplet *_applet,
 			    GTK_STATE_NORMAL, colour);
       break;
     case PANEL_PIXMAP_BACKGROUND:
-      style = gtk_style_copy (GTK_WIDGET (applet)->style);
+      style = gtk_style_copy (gtk_widget_get_style (GTK_WIDGET (applet)));
       if (style->bg_pixmap[GTK_STATE_NORMAL])
         g_object_unref (style->bg_pixmap[GTK_STATE_NORMAL]);
       style->bg_pixmap[GTK_STATE_NORMAL] = g_object_ref (pixmap);
@@ -990,10 +997,10 @@ gnome_volume_applet_background (PanelApplet *_applet,
   }
 }
 
-/* 
+/*
  * This needs to be here because not all tracks have the same volume range,
  * so you can send this function the track and a new volume and it will be
- * scaled according to the volume range of the track in question. 
+ * scaled according to the volume range of the track in question.
  */
 
 void
@@ -1141,7 +1148,7 @@ gnome_volume_applet_refresh (GnomeVolumeApplet *applet,
     applet->state = STATE (volume, mute);
 
     if (applet->dock) {
-      gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON (applet->dock->mute), 
+      gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON (applet->dock->mute),
 				    mute);
     }
   }
@@ -1199,10 +1206,10 @@ cb_notify_message (GstBus *bus, GstMessage *message, gpointer data)
   gint mute;
   gdouble volume;
 
-  if (applet->tracks == NULL || 
+  if (applet->tracks == NULL ||
       GST_MESSAGE_SRC (message) != GST_OBJECT (applet->mixer)) {
     /* No tracks, or not from our mixer - can't update anything anyway */
-    return; 
+    return;
   }
 
   volume = mute = -1;
@@ -1307,7 +1314,7 @@ cb_gconf (GConfClient *client,
   }
   key += strlen (keyroot);
   g_free (keyroot);
-  
+
   g_list_free(applet->elements);
   applet->elements = gnome_volume_applet_create_mixer_collection ();
 
@@ -1328,7 +1335,7 @@ cb_gconf (GConfClient *client,
             gst_element_set_state (item->data, GST_STATE_READY);
             if (gst_element_get_state (item->data, NULL, NULL, -1) != GST_STATE_CHANGE_SUCCESS)
               continue;
-	    
+
             /* save */
             gst_object_replace ((GstObject **) &applet->mixer, item->data);
             gst_element_set_state (old_element, GST_STATE_NULL);
@@ -1355,8 +1362,8 @@ cb_gconf (GConfClient *client,
 	first_track = g_list_first (active_tracks)->data;
 
         /* dock */
-	gtk_adjustment_set_value (applet->adjustment, 
-				  gnome_volume_applet_get_volume (applet->mixer, 
+	gtk_adjustment_set_value (applet->adjustment,
+				  gnome_volume_applet_get_volume (applet->mixer,
 								  first_track));
 
         /* if preferences window is open, update */
@@ -1413,7 +1420,7 @@ cb_verb (BonoboUIComponent *uic,
       g_error_free (error);
     }
   } else if (!strcmp (verbname, "About")) {
-	  
+
     const gchar *authors[] = { "Ronald Bultje <rbultje@ronald.bitfreak.net>",
 			     NULL };
 
@@ -1439,7 +1446,7 @@ cb_verb (BonoboUIComponent *uic,
     } else {
       if (applet->prefs)
         return;
-  
+
       g_list_free(applet->elements);
       applet->elements = gnome_volume_applet_create_mixer_collection ();
 
@@ -1500,4 +1507,3 @@ cb_stop_scroll_events (GtkWidget *widget,
   if (event->type == GDK_SCROLL)
     g_signal_stop_emission_by_name (widget, "event-after");
 }
-
